==> modified-shop_1.06-r4642_install.zip: modified-shop_1.06-r4642_install/shoproot/lang/german/admin/tax_rates.php <==
<?php
/* --------------------------------------------------------------
   $Id: tax_rates.php 899 2005-04-29 02:40:57Z hhgag $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(tax_rates.php,v 1.9 2003/03/13); www.oscommerce.com 
   (c) 2003	 nextcommerce (tax_rates.php,v 1.4 2003/08/1); www.nextcommerce.org

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Steuers&auml;tze');

define('TABLE_HEADING_TAX_RATE_PRIORITY', 'Priorit&auml;t');
define('TABLE_HEADING_TAX_CLASS_TITLE', 'Steuerklasse');
define('TABLE_HEADING_COUNTRIES_NAME', 'Land');
define('TABLE_HEADING_ZONE', 'Steuerzone');
define('TABLE_HEADING_TAX_RATE', 'Steuersatz');
define('TABLE_HEADING_ACTION', 'Aktion');

define('TEXT_INFO_EDIT_INTRO', 'Bitte f&uuml;hren Sie alle notwendigen &Auml;nderungen durch');
define('TEXT_INFO_DATE_ADDED', 'hinzugef&uuml;gt am:');
define('TEXT_INFO_LAST_MODIFIED', 'letzte &Auml;nderung:');
define('TEXT_INFO_CLASS_TITLE', 'Name der Steuerklasse:');
define('TEXT_INFO_COUNTRY_NAME', 'Land:');
define('TEXT_INFO_ZONE_NAME', 'Steuerzone:');
define('TEXT_INFO_TAX_RATE', 'Steuersatz (%):');
define('TEXT_INFO_TAX_RATE_PRIORITY', 'Steuers&auml;tze der selben Priorit&auml;t werden addiert, andere werden vermischt.<br /><br />Priorit&auml;t:');
define('TEXT_INFO_RATE_DESCRIPTION', 'Beschreibung:');
define('TEXT_INFO_INSERT_INTRO', 'Bitte geben Sie den neuen Steuersatz mit allen relevanten Daten ein');
define('TEXT_INFO_DELETE_INTRO', 'Sind Sie sicher, dass Sie diesen Steuersatz l&ouml;schen m&ouml;chten?');
define('TEXT_INFO_HEADING_NEW_TAX_RATE', 'Neuer Steuersatz');
define('TEXT_INFO_HEADING_EDIT_TAX_RATE', 'Steuersatz bearbeiten');
define('TEXT_INFO_HEADING_DELETE_TAX_RATE', 'Steuersatz l&ouml;schen');
?>

==> modified-shop_2.0.7.2-r14622_install.zip: modified-shop_2.0.7.2-r14622_install/shoproot/lang/german/admin/tax_rates.php <==
<?php
/* --------------------------------------------------------------
   $Id: tax_rates.php 899 2005-04-29 02:40:57Z hhgag $   

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   --------------------------------------------------------------
   based on: 
   (c) 2000-2001 The Exchange Project  (earlier name of osCommerce)
   (c) 2002-2003 osCommerce(tax_rates.php,v 1.9 2003/03/13); www.oscommerce.com 
   (c) 2003	 nextcommerce (tax_rates.php,v 1.4 2003/08/1); www.nextcommerce.org

   Released under the GNU General Public License 
   --------------------------------------------------------------*/

define('HEADING_TITLE', 'Steuers&auml;tze');

define('TABLE_HEADING_TAX_RATE_PRIORITY', 'Priorit&auml;t');
define('TABLE_HEADING_TAX_CLASS_TITLE', 'Steuerklasse');
define('TABLE_HEADING_COUNTRIES_NAME', 'Land');
define('TABLE_HEADING_ZONE', 'Steuerzone');
define('TABLE_HEADING_TAX_RATE', 'Steuersatz');
define('TABLE_HEADING_ACTION', 'Aktion');

define('TEXT_INFO_EDIT_INTRO', 'Bitte f&uuml;hren Sie alle notwendigen &Auml;nderungen durch');
define('TEXT_INFO_DATE_ADDED', 'hinzugef&uuml;gt am:');
define('TEXT_INFO_LAST_MODIFIED', 'letzte &Auml;nderung:');
define('TEXT_INFO_CLASS_TITLE', 'Name der Steuerklasse:');
define('TEXT_INFO_COUNTRY_NAME', 'Land:');
define('TEXT_INFO_ZONE_NAME', 'Steuerzone:');
define('TEXT_INFO_TAX_RATE', 'Steuersatz (%):');
define('TEXT_INFO_TAX_RATE_PRIORITY', 'Steuers&auml;tze der selben Priorit&auml;t werden addiert, andere werden vermischt.<br/><br/><b>WICHTIG:</b> F&uuml;r elektronisch erbrachte Leistungen muss diese auf 99 gesetzt werden.<br /><br />Priorit&auml;t:');
define('TEXT_INFO_RATE_DESCRIPTION', 'Beschreibung:');
define('TEXT_INFO_INSERT_INTRO', 'Bitte geben Sie den neuen Steuersatz mit allen relevanten Daten ein');
define('TEXT_INFO_DELETE_INTRO', 'Sind Sie sicher, dass Sie diesen Steuersatz l&ouml;schen m&ouml;chten?');
define('TEXT_INFO_HEADING_NEW_TAX_RATE', 'Neuer Steuersatz');
define('TEXT_INFO_HEADING_EDIT_TAX_RATE', 'Steuersatz bearbeiten');
define('TEXT_INFO_HEADING_DELETE_TAX_RATE', 'Steuersatz l&ouml;schen');
?>
